//
//  CommandClassesPublic.h
//  Part of Z-Way.C library
//
//  Created by Alex Skalozub on 2/1/12.
//  Based on Z-Way source code written by Christian Paetz and Poltorak Serguei
//
//  Copyright (c) 2012 Z-Wave.Me
//  All rights reserved
//  info@z-wave.me
//
//  This source file is subject to the terms and conditions of the
//  Z-Wave.Me Software License Agreement which restricts the manner
//  in which it may be used.
//

#ifndef zway_command_classes_public_h
#define zway_command_classes_public_h


// Command Class Basic //

// Send Basic Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_basic_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Basic Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: value
// Value
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_basic_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE value, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Wakeup //

// Send Wakeup Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_wakeup_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Wakeup CapabilityGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_wakeup_capabilities_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Wakeup NoMoreInformation (Sleep)
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_wakeup_sleep(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Wakeup Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: interval
// Wakeup interval in seconds
//
// @param: notification_node_id
// Node Id to be notified about wakeup
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_wakeup_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int interval, ZWBYTE notification_node_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class NoOperation //

// Send NoOperation empty packet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_nop_send(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Battery //

// Send Battery Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_battery_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class ManufacturerSpecific //

// Send ManufacturerSpecific Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_manufacturer_specific_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Configuration //

// Send Configuration Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: parameter
// Parameter number (from 1 to 255)
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_configuration_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE parameter, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Configuration Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: parameter
// Parameter number (from 1 to 255)
//
// @param: value
// Value to be sent (negative and positive values are accepted, but will be stripped to size)
//
// @param: size
// Size of the value (1, 2 or 4 bytes). Use 0 to guess from previously reported value if any.
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_configuration_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE parameter, int value, ZWBYTE size, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Configuration SetDefault
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: parameter
// Parameter number to be set to device default
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_configuration_set_default(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE parameter, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class SensorBinary //

// Send SensorBinary Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_sensor_binary_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Association //

// Send Association Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group_id
// Group Id (from 1 to 255)
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_association_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Association Set (Add)
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group_id
// Group Id (from 1 to 255)
//
// @param: include_node
// Node to be added to the group
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_association_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group_id, ZWBYTE include_node, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Association Remove
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group_id
// Group Id (from 1 to 255)
//
// @param: exclude_node
// Node to be removed from the group
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_association_remove(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group_id, ZWBYTE exclude_node, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Association GroupingsGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_association_groupings_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Meter //

// Send Meter Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: scale
// Desired scale
// -1 for all scales
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_meter_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int scale, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Meter Reset
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_meter_reset(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Meter SupportedGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_meter_supported(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class SensorMultilevel //

// Send SensorMultilevel Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: sensor_type
// Type of sensor to be requested. -1 means all sensor types supported by the device
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_sensor_multilevel_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int sensor_type, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class SwitchAll //

// Send SwitchAll Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_all_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchAll Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: mode
// SwitchAll Mode: see definitions below
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_all_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE mode, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

#define SWITCH_ALL_SET_EXCLUDED_FROM_THE_ALL_ON_ALL_OFF_FUNCTIONALITY            0x00
#define SWITCH_ALL_SET_EXCLUDED_FROM_THE_ALL_ON_FUNCTIONALITY_BUT_NOT_ALL_OFF    0x01
#define SWITCH_ALL_SET_EXCLUDED_FROM_THE_ALL_OFF_FUNCTIONALITY_BUT_NOT_ALL_ON    0x02
#define SWITCH_ALL_SET_INCLUDED_IN_THE_ALL_ON_ALL_OFF_FUNCTIONALITY              0xFF

// Send SwitchAll Set On
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_all_set_on(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchAll Set Off
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_all_set_off(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class SwitchBinary //

// Send SwitchBinary Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_binary_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchBinary Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: value
// Value
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_binary_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE value, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class SwitchMultilevel //

// Send SwitchMultilevel Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_multilevel_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchMultilevel Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: level
// Level to be set
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_multilevel_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE level, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchMultilevel Set (with duration)
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: level
// Level to be set
//
// @param: duration
// Duration of change:
// 0 instantly
// 1-127 in seconds
// 128-254 in minutes mapped to 1-127 (value 128 is 1 minute)
// 255 use device factory default
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_multilevel_set_with_duration(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE level, ZWBYTE duration, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchMultilevel Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: dir
// Direction of change: 0 to incrase, 1 to decrase
//
// @param: ignoreStartLevel
// If set to True, device will ignore start level value and will use it's curent value
//
// @param: startLevel
// Start level to change from
//
// @param: indec
// Increment/decrement type for step
//
// @param: step
// Step to be used in level change in percentage
// 0-99 mapped to 1-100%
// 255 uses device factory default
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_multilevel_start_level_change(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE dir, ZWBOOL ignoreStartLevel, ZWBYTE startLevel, ZWBYTE indec, ZWBYTE step, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchMultilevel Set (with duration)
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: dir
// Direction of change: 0 to incrase, 1 to decrase
//
// @param: duration
// Duration of change:
// 0 instantly
// 1-127 in seconds
// 128-254 in minutes mapped to 1-127 (value 128 is 1 minute)
// 255 use device factory default
//
// @param: ignoreStartLevel
// If set to True, device will ignore start level value and will use it's curent value
//
// @param: startLevel
// Start level to change from
//
// @param: indec
// Increment/decrement type for step
//
// @param: step
// Step to be used in level change in percentage
// 0-99 mapped to 1-100%
// 255 uses device factory default
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_multilevel_start_level_change_with_duration(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE dir, ZWBYTE duration, ZWBOOL ignoreStartLevel, ZWBYTE startLevel, ZWBYTE indec, ZWBYTE step, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SwitchMultilevel StopLevelChange
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_switch_multilevel_stop_level_change(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class MultiChannelAssociation //

// Send MultiChannelAssociation Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group_id
// Group Id (from 1 to 255)
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_association_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send MultiChannelAssociation Set (Add)
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group_id
// Group Id (from 1 to 255)
//
// @param: include_node
// Node to be added to the group
//
// @param: include_instance
// Instance of the node to be added to the group
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_association_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group_id, ZWBYTE include_node, ZWBYTE include_instance, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send MultiChannelAssociation Remove
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group_id
// Group Id (from 1 to 255)
//
// @param: exclude_node
// Node to be removed from the group
//
// @param: exclude_instance
// Instance of the node to be removed from the group
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_association_remove(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group_id, ZWBYTE exclude_node, ZWBYTE exclude_instance, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send MultiChannelAssociation GroupingsGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_association_groupings_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class MultiChannel //

// Send MultiChannel Get (MultiInstance V1 command)
// Reports number of channels supporting a defined Command Class
// Depricated by MutliChannel V2 - needed for old devices only
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: cc_id
// Command Class Id in question
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE cc_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send MultiChannel EndpointFind
// Note that MultiChannel EndpointFind Report is not supported as useless. But one can still trap the response packet in logs.
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: generic
// Generic type in search
//
// @param: specific 
// Specific type in search
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_endpoint_find(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE generic, ZWBYTE specific, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send MultiChannel EndpointGet
// Get the number of available endpoints
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_endpoint_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send MultiChannel CapabilitiesGet
// Request information about the specified endpoint
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: endpoint
// Endpoint in question
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_capabilities_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE endpoint, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send MultiChannel Encapsulate
// Encapsulate data for the specified endpoint
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: endpoint
// Endpoint in question
//
// @param: length
// Length of encapsulated data
//
// @param: data
// Encapsulated data
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_multichannel_encapsulate(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE endpoint, ZWBYTE length, const ZWBYTE *data, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Node Naming //

// Send NodeNaming GetName and GetLocation
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_node_naming_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send NodeNaming GetName
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_node_naming_get_name(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send NodeNaming GetLocation
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_node_naming_get_location(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send NodeNaming SetName
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: name
// Value
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_node_naming_set_name(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWCSTR name, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send NodeNaming SetLocation
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: location
// Value
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_node_naming_set_location(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWCSTR location, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Thermostat SetPoint //

// Send ThermostatSetPoint Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: mode
// Thermostat Mode
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_thermostat_setpoint_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int mode, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send ThermostatSetPoint Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: mode
// Thermostat Mode
//
// @param: value
// temperature
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_thermostat_setpoint_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int mode, float value, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Thermostat Mode //

// Send ThermostatMode Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_thermostat_mode_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send ThermostatMode Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: mode
// Thermostat Mode
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_thermostat_mode_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE mode, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Alarm Sensor //

// Send AlarmSensor SupportedGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_alarm_sensor_supported_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send AlarmSensor Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: type
// Alarm type to get
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_alarm_sensor_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int type, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class Door Lock //

// Send DoorLock Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_door_lock_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send DoorLock Configuration Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_door_lock_configuration_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send DoorLock Configuration Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: mode
// Lock mode
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_door_lock_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE mode, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send DoorLock Configuration Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: opType
// Operation type
//
// @param: outsideState
// State of outside door handle
//
// @param: insideState
// State of inside door handle
//
// @param: lockMin
// Lock after a specified time (minutes part)
//
// @param: lockSec
// Lock after a specified time (seconds part)
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_door_lock_configuration_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE opType, ZWBYTE outsideState, ZWBYTE insideState, ZWBYTE lockMin, ZWBYTE lockSec, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);


// Command Class User Code //

// Send UserCode Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: user
// User index to get code for (1 ... maxUsers)
// 0 to get codes for all users
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_user_code_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int user, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send UserCode Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: user
// User index to set code for (1...maxUsers)
//
// @param: code
// Code to set (4...10 characters long)
//
// @param: status
// Code status to set
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_user_code_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, int user, ZWCSTR code, ZWBYTE status, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Time TimeGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_time_time_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Time DateGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_time_date_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Time TimeOffsetGet
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_time_offset_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Clock Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_clock_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send Clock Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_clock_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SceneActivation Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: sceneId
// Scene Id
//
// @param: dimmingDuration
// Dimming duration
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_scene_activation_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE sceneId, ZWBYTE dimmingDuration, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SceneControllerConf Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group
// Group Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_scene_controller_conf_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SceneControllerConf Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: group
// Group Id
//
// @param: scene
// Scene Id
//
// @param: duration
// Duration
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_scene_controller_conf_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE group, ZWBYTE scene, ZWBYTE duration, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SceneActuatorConf Get
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: scene
// Scene Id
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_scene_actuator_conf_get(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE scene, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

// Send SceneActuatorConf Set
//
// @param: zway
// ZWay object instance
//
// @param: node_id
// Destination Node Id
//
// @param: instance_id
// Instance Id
//
// @param: scene
// Scene Id
//
// @param: level
// Level
//
// @param: dimming
// Dimming
//
// @param: override
// If false then the current settings in the device is associated with the Scene Id. If true then the Level value is used
//
// @param: successCallback
// Custom function to be called on function success
// NULL if callback is not needed
//
// @param: failureCallback
// Custom function to be called on function failure
// NULL if callback is not needed
//
ZWEXPORT ZWError zway_cc_scene_actuator_conf_set(ZWay zway, ZWBYTE node_id, ZWBYTE instance_id, ZWBYTE scene, ZWBYTE level, ZWBYTE dimming, ZWBOOL override, ZJobCustomCallback successCallback, ZJobCustomCallback failureCallback, void* callbackArg);

#endif
